summaryrefslogtreecommitdiff
path: root/src/mongo/db/update/object_replace_executor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/update/object_replace_executor.h')
-rw-r--r--src/mongo/db/update/object_replace_executor.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/mongo/db/update/object_replace_executor.h b/src/mongo/db/update/object_replace_executor.h
index f9c70bde919..3f4c787e588 100644
--- a/src/mongo/db/update/object_replace_executor.h
+++ b/src/mongo/db/update/object_replace_executor.h
@@ -65,10 +65,11 @@ public:
bool allowTopLevelDollarPrefixedFields = false);
/**
* Initializes the node with the document to replace with. Any zero-valued timestamps (except
* for the _id) are updated to the current time.
*/
- explicit ObjectReplaceExecutor(BSONObj replacement);
+ explicit ObjectReplaceExecutor(BSONObj replacement, bool bypassEmptyTsReplacement = false);
/**
* Replaces the document that 'applyParams.element' belongs to with 'val'. If 'val' does not
@@ -95,6 +96,8 @@ private:
// True if '_replacementDoc' contains an _id.
bool _containsId;
+
+ bool _bypassEmptyTsReplacement = false;
};
} // namespace mongo
@@ -65,10 +65,11 @@ public:
bool allowTopLevelDollarPrefixedFields = false);
/**
- * Initializes the node with the document to replace with. Any zero-valued timestamps (except
- * for the _id) are updated to the current time.
+ * Initializes the node with the document to replace with. If 'bypassEmptyTsReplacement' is
+ * false, any zero-valued timestamps (except for the _id) will be replaced with the current
+ * time.
*/